@@ -97,7 +97,8 @@ static gboolean save_composition() {
 
 
 static void close_themeselection(){
-	clutter_container_foreach(CLUTTER_CONTAINER(jammo_get_actor_by_id("main-views-widget")), tangle_actor_hide_animated, NULL);
+	g_free(prefix_for_saving);
+	clutter_container_foreach(CLUTTER_CONTAINER(jammo_get_actor_by_id("main-views-widget")), chum_hide_this_tangle_actor, NULL);
 	clutter_actor_show(view_to_go_when_end);
 }
 
@@ -182,8 +183,7 @@ static ClutterActor* create_samplebutton(gchar* themename, gchar* variation, gch
 	animation = clutter_actor_animate_with_timeline (sample_button, 
             sine_function, 
             timeline1,
-            "opacity", 200,  //do not make it too transparency (0=transparency, 255=opaque)
-            "scale-y", 0.9,  //add some vertical scaling, this looks movement, but doesn't disturb movement
+            "height", 50.0,  //add some vertical scaling, it doesn't disturb movement
             NULL);
 	clutter_animation_set_loop (animation,TRUE);
 	g_object_unref(timeline1);
@@ -422,15 +422,15 @@ white=# because it has special meaning. Samples can't be dropped on this slot. (
 */
 static int create_backing_track_color_coding(gchar* color_coding, gfloat slot_size, gfloat y_offset,TangleWidget* parent) {
 	ClutterActor* actor;
-	ClutterColor* white  = clutter_color_new(255,255,255,   255);
-	ClutterColor* yellow = clutter_color_new(255, 255, 0,   255);
-	ClutterColor* green  = clutter_color_new(0, 255, 0,     255);
-	ClutterColor* orange = clutter_color_new(255, 165, 0,   255);
-	ClutterColor* blue   = clutter_color_new(25, 25, 112,   255);
-	ClutterColor* red    = clutter_color_new(255, 0, 0,     255);
-	ClutterColor* lblue  = clutter_color_new(100, 149, 237, 255);
-	ClutterColor* violet = clutter_color_new(148,0,211,     255);
-	ClutterColor* pink   = clutter_color_new(255,105,180,   255);
+	ClutterColor white  = { 255,255,255,   255 };
+	ClutterColor yellow = { 255, 255, 0,   255 };
+	ClutterColor green  = { 0, 255, 0,     255 };
+	ClutterColor orange = { 255, 165, 0,   255 };
+	ClutterColor blue   = { 25, 25, 112,   255 };
+	ClutterColor red    = { 255, 0, 0,     255 };
+	ClutterColor lblue  = { 100, 149, 237, 255 };
+	ClutterColor violet = { 148,0,211,     255 };
+	ClutterColor pink   = { 255,105,180,   255 };
 
 	int max=strlen(color_coding);
 	int i;
@@ -440,16 +440,16 @@ static int create_backing_track_color_coding(gchar* color_coding, gfloat slot_si
 		ClutterColor* color;
 		switch (color_coding[i])
 			{
-			case '#': color =  white         ;break;
-			case 'y': color =  yellow        ;break;
-			case 'g': color =  green         ;break;
-			case 'o': color =  orange        ;break;
-			case 'b': color =  blue          ;break;
-			case 'r': color =  red           ;break;
-			case 'l': color =  lblue         ;break;
-			case 'v': color =  violet        ;break;
-			case 'p': color =  pink          ;break;
-			default: color = white;
+			case '#': color =  &white         ;break;
+			case 'y': color =  &yellow        ;break;
+			case 'g': color =  &green         ;break;
+			case 'o': color =  &orange        ;break;
+			case 'b': color =  &blue          ;break;
+			case 'r': color =  &red           ;break;
+			case 'l': color =  &lblue         ;break;
+			case 'v': color =  &violet        ;break;
+			case 'p': color =  &pink          ;break;
+			default: color = &white;
 			}
 
 		tangle_widget_set_background_color(TANGLE_WIDGET(actor), color);	
