@@ -13,7 +13,6 @@ This is part of the sequencer.
 #include "sequencer.h"
 #include "config.h"
 #include "jammo-texture.h"
-#include "clutter_jammo.h"
 #include "../chum/chum.h" //chum_go_next()
 
 enum {
@@ -179,11 +178,8 @@ static gboolean drag_sample(ClutterActor *actor, ClutterEvent *event, gpointer d
  */
 static gboolean undrag_sample(ClutterActor *actor, ClutterEvent *event, gpointer data) {
 //	clutter_actor_hide(actor);
-	clutter_actor_destroy(actor);
 	clutter_ungrab_pointer();
-	if(actor == NULL)
-		printf("Executed!\n");
-
+	clutter_actor_destroy(actor);
 	return TRUE;
 }
 
@@ -224,9 +220,11 @@ static gboolean move_rolls(ClutterActor *actor, ClutterEvent *event, gpointer da
 		if(y > 189.9 && y < 285.1) {
 			ClutterActor *tmp_actor = get_centermost_sample_from_loop_roll(actor_array);
 			if(tmp_actor != NULL) {
-				gchar* actor_name = (char*) clutter_actor_get_name(tmp_actor);
-				ClutterActor *draggable_actor = config_respawn_loop_actor("sequencer", actor_name);
-				clutter_actor_reparent(draggable_actor, main_getStage());
+				ClutterActor *draggable_actor = clutter_texture_new();
+				CoglHandle handle = clutter_texture_get_cogl_texture(CLUTTER_TEXTURE(tmp_actor));
+				clutter_texture_set_cogl_texture(CLUTTER_TEXTURE(draggable_actor), handle);
+
+				clutter_actor_reparent(draggable_actor, jammo_get_actor_by_id("main-views-widget"));
 				clutter_actor_set_position(draggable_actor, x - 47.5, y - 47.5);
 				clutter_actor_set_reactive(draggable_actor, TRUE);
 				g_signal_connect(CLUTTER_ACTOR(draggable_actor), "motion-event", G_CALLBACK(drag_sample), NULL);
@@ -234,6 +232,7 @@ static gboolean move_rolls(ClutterActor *actor, ClutterEvent *event, gpointer da
 				clutter_grab_pointer(draggable_actor);
 				clutter_actor_set_opacity(draggable_actor, 190);
 				clutter_actor_show(draggable_actor);
+
 			}
 		}
 	}
